package bluetoothconnect;

import android.Manifest;
import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.ListView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.example.bluetooth.le.BuildConfig;
import com.example.bluetooth.le.R;
import com.example.bluetooth.prt.HPRTHelper;
import com.example.bluetooth.prt.HidConncetUtil;
import com.tbruyelle.rxpermissions.RxPermissions;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import rx.functions.Action1;

public class MainActivity extends Activity {
    private BluetoothAdapter mBluetoothAdapter;
    private HidConncetUtil mHidConncetUtil;
    private BlueBroadcastReceiver mBlueBroadcastReceiver;
    private MyBluetoothAdapter mMyBluetoothAdapter;
    private ListView mListView;
	private HPRTHelper mHelper;
	private Context mContext;
	private TextView tv_nodevice;
	private List<BluetoothDevice> mList = new ArrayList<BluetoothDevice>();
    private String strAddressList="";
    private ProgressBar mProScan;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        setTitle(BuildConfig.VERSION_NAME);
        mContext = getApplicationContext();
        initview();
        initBlue();
        initPair();
    }

    @Override
    protected void onRestart() {
        super.onRestart();
        initBlue();
        initPair();
    }

    private void initview() {
        mListView = (ListView) findViewById(R.id.listview);
        tv_nodevice = (TextView) findViewById(R.id.tv_nodevice);
        Button search = (Button) findViewById(R.id.search);
        mProScan = findViewById(R.id.progress_scan);
        search.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Log.d("SCAN", "onClick");
                setScan();
            }
        });
    }

    private void setScan() {
        RxPermissions rxPermissions = new RxPermissions(MainActivity.this);
        rxPermissions.request(Manifest.permission.BLUETOOTH_ADMIN,
                Manifest.permission.BLUETOOTH,
                Manifest.permission.ACCESS_FINE_LOCATION).subscribe(new Action1<Boolean>() {
            @Override
            public void call(Boolean aBoolean) {
                if (aBoolean){
                    //扫描蓝牙设备
                    Log.d("SCAN", "call: "+aBoolean);
                    mProScan.setVisibility(View.VISIBLE);
                    if (!mBluetoothAdapter.isDiscovering()) {
                        mBluetoothAdapter.startDiscovery();
                    }
                }
            }
        });
    }

    private void initPair(){
        if (mBluetoothAdapter == null) {
            Toast.makeText(this,getString(R.string.main_no_support),Toast.LENGTH_SHORT).show();
            //不支持蓝牙
            return;
        }
        mList.clear();
        //得到已经配对的列表
        Set<BluetoothDevice> mSet = mBluetoothAdapter.getBondedDevices();
        final Iterator mIterator = mSet.iterator();
        while (mIterator.hasNext()) {
            BluetoothDevice mBluetoothDevice = (BluetoothDevice) mIterator
                    .next();
            if(mMyBluetoothAdapter==null){
                mMyBluetoothAdapter = new MyBluetoothAdapter(MainActivity.this);
                mListView.setAdapter(mMyBluetoothAdapter);
            }
            mList.add(mBluetoothDevice);
        }
        if (mList.size()==0) {
        	tv_nodevice.setVisibility(View.VISIBLE);
		}else {
			mMyBluetoothAdapter.addData(mList);
	        mMyBluetoothAdapter.notifyDataSetChanged();
			tv_nodevice.setVisibility(View.GONE);
		}
    }

    private void initBlue() {
        //初始化广播接收
        mBlueBroadcastReceiver = new BlueBroadcastReceiver();
        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if (mBluetoothAdapter == null) {
            Toast.makeText(this,getString(R.string.main_no_support),Toast.LENGTH_SHORT).show();
            //不支持蓝牙
            return;
        }
        //如果没有打开蓝牙
        if (!mBluetoothAdapter.isEnabled()) {
            mBluetoothAdapter.enable();
        }
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
            this.mHidConncetUtil = new HidConncetUtil(this);
        }
    }


    @Override
    protected void onResume() {
        super.onResume();
        mHelper = HPRTHelper.getHPRTHelper(MainActivity.this);
        registerReceiver();
    }

    @Override
    protected void onPause() {
        super.onPause();
        this.unregisterReceiver(mBlueBroadcastReceiver);
    }

    public void registerReceiver() {
        IntentFilter localIntentFilter = new IntentFilter();
        localIntentFilter.addAction(BluetoothDevice.ACTION_FOUND);
        localIntentFilter.addAction(BluetoothDevice.ACTION_BOND_STATE_CHANGED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_CONNECTED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECT_REQUESTED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECTED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_STATE_CHANGED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_DISCOVERY_STARTED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_DISCOVERY_FINISHED);
        this.registerReceiver(mBlueBroadcastReceiver, localIntentFilter);
    }

    private class BlueBroadcastReceiver  extends BroadcastReceiver{

        @Override
        public void onReceive(Context context, Intent intent) {
            String str = intent.getAction();
            if (BluetoothDevice.ACTION_FOUND.equals(str)) {
//            	Log.i("SCAN", "onReceive" + str);
            	//通过广播接收到了BluetoothDevice
            	final BluetoothDevice localBluetoothDevice = (BluetoothDevice) intent
            			.getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
            	if (localBluetoothDevice != null) {
            		if(mMyBluetoothAdapter==null){
            			mMyBluetoothAdapter = new MyBluetoothAdapter(MainActivity.this);
            			mListView.setAdapter(mMyBluetoothAdapter);
            		}
            		boolean isContain=true;
                    for (BluetoothDevice bluetoothDevice:mList) {
                        if(bluetoothDevice.getAddress().equals(localBluetoothDevice.getAddress()))
                                isContain=false;
                    }
                    if (isContain){
                        if (!TextUtils.isEmpty(localBluetoothDevice.getName())){
                            if(localBluetoothDevice.getName().contains("HPRT")){
                                mList.add(localBluetoothDevice);
                                mMyBluetoothAdapter.addData(mList);
                                mMyBluetoothAdapter.notifyDataSetChanged();
                            }
                        }
                    }
            	}
			}
            if (BluetoothAdapter.ACTION_DISCOVERY_FINISHED.equals(str)){
                mProScan.setVisibility(View.GONE);
            }
        }
    }
    @Override
    protected void onStop() {
    	// TODO Auto-generated method stub
    	super.onStop();
    }
    @Override
    protected void onDestroy() {
    	// TODO Auto-generated method stub
    	super.onDestroy();
//    	unregisterReceiver(mBlueBroadcastReceiver);
    	if (mHelper!=null) {
    		mHelper.disconnect();
		}
    }
}
