package bluetoothconnect;

import android.app.Activity;
import android.app.ProgressDialog;
import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.example.bluetooth.le.MenuActivity;
import com.example.bluetooth.le.R;
import com.example.bluetooth.prt.HPRTHelper;
import com.example.bluetooth.prt.HPRTHelper.onConnect;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by liushen on 2016/5/31.
 */
public class MyBluetoothAdapter extends BaseAdapter {
    private List<BluetoothDevice> mList = new ArrayList<BluetoothDevice>();
    private Context mContext;
	private HPRTHelper mHprt;
    public MyBluetoothAdapter(List<BluetoothDevice> mList, Context mContext) {
        this.mList = mList;
        this.mContext = mContext;
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
            mHprt = HPRTHelper.getHPRTHelper(mContext);
        }
    }
    public MyBluetoothAdapter(Context mContext) {
        this.mContext = mContext;
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
        	mHprt = HPRTHelper.getHPRTHelper(mContext);
        }
    }

    @Override
    public int getCount() {
        return mList.size();
    }

    @Override
    public Object getItem(int position) {
        return mList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    public void addData(List<BluetoothDevice> bluetoothDevice){
    	mList.clear();
        mList.addAll(bluetoothDevice);
    }
    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder = null;
        if(convertView==null){
            convertView = View.inflate(mContext,R.layout.blue_list_item,null);
            viewHolder = new ViewHolder(convertView);
            convertView.setTag(viewHolder);
        }else{
            viewHolder = (ViewHolder) convertView.getTag();
        }
        initData(position,viewHolder);
        return convertView;
    }

    private void initData(int position,ViewHolder viewHolder) {
        final BluetoothDevice bluetoothDevice = mList.get(position);
        viewHolder.bluehandlename.setText(bluetoothDevice.getName());
        viewHolder.bluehandlebond.setText(bluetoothDevice.getAddress());
        viewHolder.connect.setEnabled(true);
        viewHolder.connect_ble.setEnabled(true);

        viewHolder.connect_ble.setOnClickListener(new View.OnClickListener(){
            @Override
            public void onClick(View v) {
               final ProgressDialog progressDialog = new ProgressDialog(mContext);
                progressDialog.setTitle(R.string.title_warm_tips);
                progressDialog.setMessage(mContext.getString(R.string.title_connecting));
                progressDialog.show();
                new Thread(){
                    @Override
                    public void run() {
                        super.run();
                        synchronized (this){
                            mHprt.setDevice(bluetoothDevice);
                            mHprt.buleconnectbyType(BluetoothDevice.DEVICE_TYPE_LE, mContext,new onConnect() {
                                @Override
                                public void succeed() {
                                    // TODO Auto-generated method stub
                                    ((Activity)mContext).runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            progressDialog.dismiss();
                                            Toast.makeText(mContext, mContext.getString(R.string.title_connetion_successful), Toast.LENGTH_SHORT).show();
                                            Intent intent = new Intent((Activity)mContext, MenuActivity.class);
                                            intent.putExtra("ACTION_TYPE", BluetoothDevice.DEVICE_TYPE_LE);
                                            mContext.startActivity(intent);
                                        }
                                    });
                                }

                                @Override
                                public void failure() {
                                    // TODO Auto-generated method stub
                                    ((Activity)mContext).runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            progressDialog.dismiss();
                                            Toast.makeText(mContext, mContext.getString(R.string.title_connetion_failed), Toast.LENGTH_SHORT).show();
                                        }
                                    });
                                }
                            });
                        }
                    }
                }.start();
            }
        });

        viewHolder.connect.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final ProgressDialog progressDialog = new ProgressDialog(mContext);
                progressDialog.setTitle(R.string.title_warm_tips);
                progressDialog.setMessage(mContext.getString(R.string.title_connecting));
                progressDialog.show();
                new Thread(){
                    @Override
                    public void run() {
                        super.run();
                        synchronized (this){
                            mHprt.setDevice(bluetoothDevice);
                            mHprt.buleconnectbyType(BluetoothDevice.DEVICE_TYPE_CLASSIC, mContext,new onConnect() {
                                @Override
                                public void succeed() {
                                    // TODO Auto-generated method stub
                                    Log.d("TAG","CLASS Connection Succeed");
                                    ((Activity)mContext).runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            if (!((Activity)mContext).isFinishing()){
                                                progressDialog.dismiss();
                                                Toast.makeText(mContext, mContext.getString(R.string.title_connetion_successful), Toast.LENGTH_SHORT).show();
                                            }
                                            Intent intent = new Intent((Activity)mContext, MenuActivity.class);
                                            intent.putExtra("ACTION_TYPE", BluetoothDevice.DEVICE_TYPE_CLASSIC);
                                            mContext.startActivity(intent);
                                        }
                                    });
                                }

                                @Override
                                public void failure() {
                                    Log.d("TAG","CLASS Connection Failure");
                                    // TODO Auto-generated method stub
                                    ((Activity)mContext).runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            progressDialog.dismiss();
                                            Toast.makeText(mContext, mContext.getString(R.string.title_connetion_failed), Toast.LENGTH_SHORT).show();
                                        }
                                    });
                                }
                            });
                        }
                    }
                }.start();
            }
        });
    }

    /**
     * 判断是否配对并设置配置状态
     * @param bluetoothDevice
     */
    private void isBonded(BluetoothDevice bluetoothDevice,ViewHolder viewHolder){
        int state =  bluetoothDevice.getBondState();
        switch (state) {
            case BluetoothDevice.BOND_NONE:
                viewHolder.bluehandlebond.setText("未配对");
                break;
            case BluetoothDevice.BOND_BONDING:
                viewHolder.bluehandlebond.setText("配对中...");
                break;
            case BluetoothDevice.BOND_BONDED:
                viewHolder.bluehandlebond.setText("已配对");
                break;
        }
    }


    public class ViewHolder {
        public final TextView bluehandlename;
        public final TextView bluehandlebond;
        public final Button connect;
        public final Button connect_ble;
        public final View root;

        public ViewHolder(View root) {
            bluehandlename = (TextView) root.findViewById(R.id.blue_handle_name);
            bluehandlebond = (TextView) root.findViewById(R.id.blue_handle_bond);
            connect = (Button) root.findViewById(R.id.connect);
            connect_ble = (Button) root.findViewById(R.id.connect_ble);
            this.root = root;
        }
    }
}
