package com.example.bluetooth.le;


import android.app.Activity;
import android.app.AlertDialog.Builder;
import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.example.bluetooth.prt.HPRTHelper;
import com.example.bluetooth.prt.HPRTHelper.onDeviceName;
import com.example.bluetooth.prt.HPRTHelper.onElectricity;
import com.example.bluetooth.prt.HPRTHelper.onReaddeviceversion;
import com.example.bluetooth.prt.HPRTHelper.onWorkModel;
import com.example.bluetooth.prt.Utiltools;

import java.lang.ref.WeakReference;

public class MenuActivity extends Activity implements OnClickListener{
	private HPRTHelper mHelper;
	private TextView tv_version;
	private TextView tv_electricity;
	private TextView tv_work_model;
	private Context mContext;
	private int GATT=1;
	private int HID=2;
	private boolean isgetWork=false;
	private int WORK_MODEL=0;
	private TextView tv_voltage;
	private TextView tv_device_name;
	private MyHandler myHandler;
	private boolean bInitiate = false;
	private int action_type = 0;


	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_menu);
		mContext = getApplicationContext();
		myHandler = new MyHandler(this);
		Intent intent =getIntent();
		//getXxxExtra方法获取Intent传递过来的数据
		action_type = intent.getIntExtra("ACTION_TYPE", 0);
		init(action_type);
	}

	private void init(int type) {
		tv_version = (TextView) findViewById(R.id.tv_version);
		tv_version.setOnClickListener(this);
		tv_electricity = (TextView) findViewById(R.id.tv_electricity);
		tv_electricity.setOnClickListener(this);
		tv_work_model = (TextView) findViewById(R.id.tv_work_model);
		tv_work_model.setOnClickListener(this);
		tv_voltage = (TextView) findViewById(R.id.tv_voltage);
		tv_voltage.setOnClickListener(this);
		tv_device_name = (TextView) findViewById(R.id.tv_devicename);
		tv_device_name.setOnClickListener(this);
		mHelper = HPRTHelper.getHPRTHelper(MenuActivity.this);
		Utiltools.d("TAG","type:"+type);
		if (type == BluetoothDevice.DEVICE_TYPE_CLASSIC) {
			bInitiate = true;
			myHandler.obtainMessage(MyHandler.MESSAGE_READ_VERSIOM).sendToTarget();
		} else {
			initData();
		}
		mHelper.bluetoothFeedback(new HPRTHelper.onDisconnect() {
			@Override
			public void succeed() {
				if (!isFinishing())
				Toast.makeText(mContext,"Bluetooth Disconnection",Toast.LENGTH_SHORT).show();
			}
		});
	}

	private static class MyHandler extends Handler {
		private static final int MESSAGE_READ_VERSIOM = 1;
		private static final int MESSAGE_GET_DEVICE_NAME = 2;
		private static final int MESSAGE_GET_POWER = 3;
		private static final int MESSAGE_GET_WORK_MODEL = 4;

		private final WeakReference<MenuActivity> host;

		public MyHandler(MenuActivity view)
		{
			host = new WeakReference<MenuActivity>(view);
		}

		@Override
		public void handleMessage(Message msg) {
			final MenuActivity view = host.get();
			switch (msg.what) {
				case MESSAGE_READ_VERSIOM:
					view.readversion();
					break;
				case MESSAGE_GET_DEVICE_NAME:
					view.getDeviceName();
					break;
				case MESSAGE_GET_POWER:
					view.getPower();
					break;
				case MESSAGE_GET_WORK_MODEL:
					view.getWorkModel();
					break;
			}
			super.handleMessage(msg);
		}
	}

	private void initData() {
		readversion();
		getDeviceName();
		getPower();
		getWorkModel();
	}
	//获取设备名称
	private void getDeviceName(){
		mHelper.getDeviceName(new onDeviceName() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				tv_device_name.setText("name: "+Util.byteASCIIstr(data));
				if (bInitiate) {
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_POWER);
				}

			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_device_name.setText("get device name");
				if (bInitiate) {
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_POWER);
				}

			}
		});
	}
	
	//获取版本号
	private void readversion(){
		mHelper.setReaddeviceversion(new onReaddeviceversion() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				if (action_type == BluetoothDevice.DEVICE_TYPE_CLASSIC) {
					tv_version.setText("version: "+ data[data.length-3]+data[data.length-2]);
				} else if (action_type == BluetoothDevice.DEVICE_TYPE_LE){
					tv_version.setText("version: "+ data[data.length-1] + data[data.length-2]);
				}
				if (bInitiate) {
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_DEVICE_NAME);
				}
			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_version.setText("version: 0.9");
				if (bInitiate){
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_DEVICE_NAME);
				}
			}
		});
	}
	private void getPower(){
		mHelper.getElectricity(new onElectricity() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				tv_electricity.setText("battery: "+data[4]+"%");
				String parseHex =HPRTHelper.bytetohex(data[2])+HPRTHelper.bytetohex(data[3]);
				tv_voltage.setText("volage: "+Integer.parseInt(parseHex.trim(),16)+"mV");
				if (bInitiate) {
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_WORK_MODEL);
				}
			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_electricity.setText("get battery");
				tv_voltage.setText("get volage");
				if (bInitiate) {
					myHandler.sendEmptyMessage(MyHandler.MESSAGE_GET_WORK_MODEL);
				}
			}
		});
	}
	private void getWorkModel(){
		mHelper.getWorkModel(new onWorkModel() {
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				if (data[2]==1||data[2]==3) {
					tv_work_model.setText("mode: GATT|SPP");
					WORK_MODEL=GATT;
					isgetWork=true;
				}else if(data[2]==2){
					tv_work_model.setText("mode: HID");
					WORK_MODEL=HID;
					isgetWork=true;
				}else{
					tv_work_model.setText("get mode");
					isgetWork=false;
				}

				if (bInitiate) {
					bInitiate = false;
				}
			}
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_work_model.setText("get mode");
				isgetWork=false;

				if (bInitiate) {
					bInitiate = false;
				}
			}
		});
	}
	public void setting(View view){
		startActivity(new Intent(MenuActivity.this, SettingActivity.class));
	}
	public void workmodel(View view){
		if (isgetWork) {
			View contentView = LayoutInflater.from(mContext).inflate(
					R.layout.dialog_work_model, null);
			Builder builder = Util.DialogView(MenuActivity.this, contentView);
			final RadioGroup rg_work_model = (RadioGroup) contentView.findViewById(R.id.rg_work_model);
			switch (WORK_MODEL) {
			case 1:
				rg_work_model.check(R.id.rb_workmodel_gatt);
				break;
			case 2:
				rg_work_model.check(R.id.rb_workmodel_hid);
				break;
			default:
				break;
			}
			builder.setNegativeButton("OK", new DialogInterface.OnClickListener() {
				
				@Override
				public void onClick(DialogInterface dialog, int which) {
					// TODO Auto-generated method stub
					switch (rg_work_model.getCheckedRadioButtonId()) {
					case R.id.rb_workmodel_gatt:
						if(mHelper.setWorkModel(GATT)){
							mHelper.disconnect();
							Util.ToastMessage(mContext, "set succeed");
							finish();
						}else{
							Util.ToastMessage(mContext, "set failed");
						}
						break;
					case R.id.rb_workmodel_hid:
						if(mHelper.setWorkModel(HID)){
							mHelper.disconnect();
							Util.ToastMessage(mContext, "set succeed");
							finish();
						}else{
							Util.ToastMessage(mContext, "set failed");
						}
						break;

					default:
						break;
					}
				}
			});
			builder.setNeutralButton("cancel", null);
			builder.show();
		}else {
			Util.ToastMessage(mContext, "get mode failed, do reconnect");
		}
	}
	public void scandata(View view){
		startActivity(new Intent(this, ScanDataActivity.class));
	}
	public void functions(View view){
		startActivity(new Intent(this, FunctionsActivity.class));
	}
	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		if (mHelper!=null) {
    		mHelper.disconnect();
		}
	}

	@Override
	public void onClick(View v) {
		// TODO Auto-generated method stub
		switch (v.getId()) {
		case R.id.tv_version:
			if ("get version".equals(tv_version.getText())) {
				readversion();
			}
			break;
		case R.id.tv_electricity:
			if ("get battery".equals(tv_electricity.getText())) {
				getPower();
			}
			break;
		case R.id.tv_voltage:
			if ("get volage".equals(tv_voltage.getText())) {
				getPower();
			}
			break;
		case R.id.tv_work_model:
			if ("get mode".equals(tv_work_model.getText())) {
				getWorkModel();
			}
			break;
		case R.id.tv_devicename:
			if ("get device name".equals(tv_device_name.getText())) {
				getDeviceName();
			}
			break;

		default:
			break;
		}
	}
	public void deviceName(View view){
		View contentView = LayoutInflater.from(mContext).inflate(
				R.layout.dialog_device_name, null);
		Builder builder = Util.DialogView(MenuActivity.this, contentView);
		final EditText ed_device_name = (EditText) contentView.findViewById(R.id.ed_device_name);
		builder.setPositiveButton("OK", new DialogInterface.OnClickListener() {
			
			@Override
			public void onClick(DialogInterface dialog, int which) {
				// TODO Auto-generated method stub
				if(mHelper.setDeviceName(ed_device_name.getText().toString())){
					initData();
					Util.ToastMessage(mContext, "Modify succeed");
				}else{
					Util.ToastMessage(mContext, "Modify failed");
				}
			}
		});
		builder.setNegativeButton("cancel", null);
		builder.show();
	}
	public void Temporarily(View view){
		startActivity(new Intent(MenuActivity.this, TemporarilyActivity.class));
	}
}
